==> quantum_serverless-0.0.4-py3-none-any.whl: quantum_serverless/core/tracing.py <==
# This code is a Qiskit project.
#
# (C) Copyright IBM 2023.
#
# This code is licensed under the Apache License, Version 2.0. You may
# obtain a copy of this license in the LICENSE.txt file in the root directory
# of this source tree or at http://www.apache.org/licenses/LICENSE-2.0.
#
# Any modifications or derivative works of this code must retain this
# copyright notice, and modified files need to carry a notice indicating
# that they have been altered from the originals.

"""
=================================================
Provider (:mod:`quantum_serverless.core.tracing`)
=================================================

.. currentmodule:: quantum_serverless.core.tracing

Quantum serverless tracing
==========================

.. autosummary::
    :toctree: ../stubs/

    get_tracer
"""

import os
from typing import Dict, Optional

from opentelemetry import trace
from opentelemetry.exporter.jaeger.thrift import JaegerExporter
from opentelemetry.sdk.resources import SERVICE_NAME, Resource
from opentelemetry.sdk.trace import TracerProvider
from opentelemetry.sdk.trace.export import (
    SimpleSpanProcessor,
)
from opentelemetry.trace import Tracer
from opentelemetry.trace.propagation.tracecontext import TraceContextTextMapPropagator

from quantum_serverless.core.constrants import (
    OT_PROGRAM_NAME,
    OT_PROGRAM_NAME_DEFAULT,
    OT_JAEGER_HOST_KEY,
    OT_JAEGER_PORT_KEY,
    OT_TRACEPARENT_ID_KEY,
    OT_SPAN_DEFAULT_NAME,
    OT_LABEL_CALL_LOCATION,
)


def get_tracer(
    instrumenting_module_name: str,
    agent_host: Optional[str] = None,
    agent_port: Optional[int] = None,
) -> Tracer:
    """Returns tracer for context.

    If agent host and ports are not provided default tracer will be returned.
    If agent host and ports are provided then will include Jaeger as provider.

    Args:
        instrumenting_module_name: module name for tracing
        agent_host: jaeger agent host
        agent_port: jaeger agent port

    Returns:
        tracer
    """
    resource = Resource(
        attributes={
            SERVICE_NAME: f"qs.{os.environ.get(OT_PROGRAM_NAME, OT_PROGRAM_NAME_DEFAULT)}"
        }
    )
    provider = TracerProvider(resource=resource)
    if agent_host is not None and agent_port is not None:
        jaeger_exporter = JaegerExporter(
            agent_host_name=agent_host,
            agent_port=agent_port,
        )
        provider.add_span_processor(SimpleSpanProcessor(jaeger_exporter))
    trace._set_tracer_provider(provider, log=False)  # pylint: disable=protected-access
    return trace.get_tracer(instrumenting_module_name)


def _trace_env_vars(env_vars: dict, location: Optional[str] = None):
    """Sets env variables for tracing across executable function.

    Args:
        env_vars: original env variables dict to inject traceparent
        location: where trace was called

    Returns:
        dict of env variables
    """
    tracer = get_tracer(
        __name__,
        agent_host=os.environ.get(OT_JAEGER_HOST_KEY, None),
        agent_port=int(os.environ.get(OT_JAEGER_PORT_KEY, 6831)),
    )
    if env_vars.get(OT_TRACEPARENT_ID_KEY, None) is not None:
        env_vars[OT_TRACEPARENT_ID_KEY] = env_vars.get(OT_TRACEPARENT_ID_KEY)
    elif os.environ.get(OT_TRACEPARENT_ID_KEY) is not None:
        env_vars[OT_TRACEPARENT_ID_KEY] = os.environ.get(OT_TRACEPARENT_ID_KEY)
    else:
        carrier: Dict[str, str] = {}
        with tracer.start_as_current_span(
            os.environ.get(OT_PROGRAM_NAME, OT_SPAN_DEFAULT_NAME)
        ) as span:
            if location is not None:
                span.set_attribute(OT_LABEL_CALL_LOCATION, location)
            TraceContextTextMapPropagator().inject(carrier)
        traceparent = carrier.get(
            TraceContextTextMapPropagator._TRACEPARENT_HEADER_NAME  # pylint:disable=protected-access
        )
        env_vars[OT_TRACEPARENT_ID_KEY] = traceparent
        os.environ[OT_TRACEPARENT_ID_KEY] = traceparent
    return env_vars

==> quantum_serverless-0.0.6-py3-none-any.whl: quantum_serverless/core/tracing.py <==
# This code is a Qiskit project.
#
# (C) Copyright IBM 2023.
#
# This code is licensed under the Apache License, Version 2.0. You may
# obtain a copy of this license in the LICENSE.txt file in the root directory
# of this source tree or at http://www.apache.org/licenses/LICENSE-2.0.
#
# Any modifications or derivative works of this code must retain this
# copyright notice, and modified files need to carry a notice indicating
# that they have been altered from the originals.

"""
=================================================
Provider (:mod:`quantum_serverless.core.tracing`)
=================================================

.. currentmodule:: quantum_serverless.core.tracing

Quantum serverless tracing
==========================

.. autosummary::
    :toctree: ../stubs/

    get_tracer
"""

import os
from typing import Dict, Optional

from opentelemetry import trace
from opentelemetry.exporter.jaeger.thrift import JaegerExporter
from opentelemetry.sdk.resources import SERVICE_NAME, Resource
from opentelemetry.sdk.trace import TracerProvider
from opentelemetry.sdk.trace.export import (
    SimpleSpanProcessor,
)
from opentelemetry.trace import Tracer
from opentelemetry.trace.propagation.tracecontext import TraceContextTextMapPropagator

from quantum_serverless.core.constants import (
    OT_PROGRAM_NAME,
    OT_PROGRAM_NAME_DEFAULT,
    OT_JAEGER_HOST_KEY,
    OT_JAEGER_PORT_KEY,
    OT_TRACEPARENT_ID_KEY,
    OT_SPAN_DEFAULT_NAME,
    OT_LABEL_CALL_LOCATION,
)


def get_tracer(
    instrumenting_module_name: str,
    agent_host: Optional[str] = None,
    agent_port: Optional[int] = None,
) -> Tracer:
    """Returns tracer for context.

    If agent host and ports are not provided default tracer will be returned.
    If agent host and ports are provided then will include Jaeger as provider.

    Args:
        instrumenting_module_name: module name for tracing
        agent_host: jaeger agent host
        agent_port: jaeger agent port

    Returns:
        tracer
    """
    resource = Resource(
        attributes={
            SERVICE_NAME: f"qs.{os.environ.get(OT_PROGRAM_NAME, OT_PROGRAM_NAME_DEFAULT)}"
        }
    )
    provider = TracerProvider(resource=resource)
    if agent_host is not None and agent_port is not None:
        jaeger_exporter = JaegerExporter(
            agent_host_name=agent_host,
            agent_port=agent_port,
        )
        provider.add_span_processor(SimpleSpanProcessor(jaeger_exporter))
    trace._set_tracer_provider(provider, log=False)  # pylint: disable=protected-access
    return trace.get_tracer(instrumenting_module_name)


def _trace_env_vars(env_vars: dict, location: Optional[str] = None):
    """Sets env variables for tracing across executable function.

    Args:
        env_vars: original env variables dict to inject traceparent
        location: where trace was called

    Returns:
        dict of env variables
    """
    tracer = get_tracer(
        __name__,
        agent_host=os.environ.get(OT_JAEGER_HOST_KEY, None),
        agent_port=int(os.environ.get(OT_JAEGER_PORT_KEY, 6831)),
    )
    if env_vars.get(OT_TRACEPARENT_ID_KEY, None) is not None:
        env_vars[OT_TRACEPARENT_ID_KEY] = env_vars.get(OT_TRACEPARENT_ID_KEY)
    elif os.environ.get(OT_TRACEPARENT_ID_KEY) is not None:
        env_vars[OT_TRACEPARENT_ID_KEY] = os.environ.get(OT_TRACEPARENT_ID_KEY)
    else:
        carrier: Dict[str, str] = {}
        with tracer.start_as_current_span(
            os.environ.get(OT_PROGRAM_NAME, OT_SPAN_DEFAULT_NAME)
        ) as span:
            if location is not None:
                span.set_attribute(OT_LABEL_CALL_LOCATION, location)
            TraceContextTextMapPropagator().inject(carrier)
        traceparent = carrier.get(
            TraceContextTextMapPropagator._TRACEPARENT_HEADER_NAME  # pylint:disable=protected-access
        )
        env_vars[OT_TRACEPARENT_ID_KEY] = traceparent
        os.environ[OT_TRACEPARENT_ID_KEY] = traceparent
    return env_vars
